aboutsummaryrefslogtreecommitdiffstats
path: root/apps/app_dial.c
diff options
context:
space:
mode:
Diffstat (limited to 'apps/app_dial.c')
-rw-r--r--apps/app_dial.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/apps/app_dial.c b/apps/app_dial.c
index 3a942ffc2..f1dd6ef3d 100644
--- a/apps/app_dial.c
+++ b/apps/app_dial.c
@@ -1856,8 +1856,9 @@ static int dial_exec_full(struct ast_channel *chan, void *data, struct ast_flags
sentringing = 0;
ast_indicate(chan, -1);
}
/* Be sure no generators are left on it */
ast_deactivate_generator(chan);
+ chan->visible_indication = 0;
/* Make sure channels are compatible */
res = ast_channel_make_compatible(chan, peer);
if (res < 0) {
@@ -1856,8 +1856,9 @@ static int dial_exec_full(struct ast_channel *chan, void *data, struct ast_flags
ast_indicate(chan, -1);
}
- /* Be sure no generators are left on it */
+ /* Be sure no generators are left on it and reset the visible indication */
ast_deactivate_generator(chan);